import 'package:ocg_app/ocg_app.dart';
import 'package:bloc/bloc.dart';
import 'package:flutter/material.dart';
import 'package:ocg_user/ocg_user.dart';

import '../../repository/login.dart';
import 'event.dart';
import 'state.dart';

class LoginBloc extends Bloc<LoginEvent, LoginState> {
  final LoginRepository repository;
  final UserRepository userRepository;
  LoginBloc(
    this.repository,
    this.userRepository,
  ) : super(LoginIdleState());

  @override
  Stream<LoginState> mapEventToState(LoginEvent event) async* {
    if (event is LoginCheckEvent) {
      AppResponse<bool> loginResponse = await repository.isLoggedIn();
      if (loginResponse.isSuccess && loginResponse.data) {
        var userResponse = await userRepository.getSelf();
        debugPrint("Login Checked ${userResponse.data}");
        if (userResponse.isSuccess)
          yield LoginExistState(userResponse.data);
        else {
          yield LoginNotCompleteState();
        }
      } else {
        yield LoginNotCompleteState();
      }
    }
    if (event is LoginSignupEvent) {
      yield LoginLoadingState();
      AppResponse<bool> response = await repository.loginUser(event.user);
      if (response.isSuccess && response.data) {
        yield LoginExistState(event.user);
      } else {
        yield LoginErrorState(response.error);
      }
    }
  }
}
