import 'package:ocg_app/ocg_app.dart';
import 'package:flutter/material.dart';
import 'package:path_provider/path_provider.dart';
import 'package:sembast/sembast.dart';
import 'package:sembast/sembast_io.dart';

class LoginDatabase {
  static const String _dbPath = 'user.db';
  static Database _db;
  static StoreRef _storeRef;
  static const String USER = "user";
  static const String TOKEN = "token";

  Future<void> open() async {
    if (_db != null) {
      return;
    }
    final appDocDir = await getApplicationDocumentsDirectory();
    _db = await databaseFactoryIo.openDatabase("${appDocDir.path}/$_dbPath",
        version: 1);
    _storeRef = StoreRef.main();
    return;
  }

  bool get isOpened => _db != null;

  Future<AppResponse<bool>> storeUser(String id) async {
    try {
      await _storeRef.record(USER).put(_db, id);
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "${e.toString()}");
    }
  }

  Future<AppResponse<String>> getUser() async {
    try {
      var result = await _storeRef.record(USER).get(_db) as String;
      if (result == null) {
        return AppResponse.named(error: "User does not exists");
      }
      return AppResponse.named(data: result);
    } catch (e) {
      debugPrint("Error $e");

      return AppResponse.named(error: "${e.toString()}");
    }
  }

  Future<AppResponse<bool>> saveToken(AppToken token) async {
    try {
      _storeRef.record(TOKEN).put(_db, token.toJson());
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("DB Error $e");
      return AppResponse.named(error: "${e.toString()}");
    }
  }

  Future<AppResponse<AppToken>> getToken() async {
    try {
      var result = Map<String, dynamic>.from(
          await _storeRef.record(TOKEN).get(_db) as Map);
      if (result == null) {
        return AppResponse.named(error: "Token does not exists");
      }
      return AppResponse.named(data: AppToken.fromJson(result));
    } catch (e) {
      return AppResponse.named(error: "${e.toString()}");
    }
  }
}
