import 'package:ocg_app/ocg_app.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_login/ocg_login.dart';
import 'package:ocg_login/src/widgets/continue_button.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:ocg_user/ocg_user.dart';

import '../blocs/login/bloc.dart';
import '../blocs/login/state.dart';

class LoginProfileScreen extends StatefulWidget {
  @override
  _LoginProfileScreenState createState() => _LoginProfileScreenState();
}

class _LoginProfileScreenState extends State<LoginProfileScreen> {
  final GlobalKey<FormState> key = GlobalKey<FormState>();
  final GlobalKey<ScaffoldState> scaffoldKey = GlobalKey<ScaffoldState>();

  String email;
  String password;

  @override
  void initState() {
    super.initState();
    email = '';
    password = '';
  }

  @override
  Widget build(BuildContext context) {
    return BlocListener<LoginBloc, LoginState>(
      listener: (context, state) {
        if (state is LoginExistState) {
          AppActionHandler.of(context).goHome();
        }
        if (state is LoginErrorState) {
          scaffoldKey.currentState
              .showSnackBar(SnackBar(content: Text('${state.error}')));
        }
      },
      child: BlocBuilder<LoginBloc, LoginState>(builder: (context, loginState) {
        return ModalProgressHUD(
          inAsyncCall: loginState is LoginLoadingState,
          child: buildScreen(),
        );
      }),
    );
  }

  Widget buildScreen() {
    return Scaffold(
      key: scaffoldKey,
      body: SingleChildScrollView(
        child: SizedBox(
          height: MediaQuery.of(context).size.height,
          child: Padding(
            padding: const EdgeInsets.symmetric(vertical: 16, horizontal: 20),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: [
                Expanded(
                  child: Container(),
                  flex: 2,
                ),
                Hero(
                  tag: "Splash",
                  child: Container(
                    alignment: Alignment.center,
                    child: SizedBox(
                        width: MediaQuery.of(context).size.width / 2.5,
                        height: MediaQuery.of(context).size.width / 2.5,
                        child: FlutterLogo()),
                  ),
                ),
                SizedBox(
                  height: 60,
                ),
                RichText(
                  text: TextSpan(children: [
                    TextSpan(
                      text: "Welcome,\n",
                      style: TextStyle(
                        color: Color(0xff2a2526),
                        fontSize: 27,
                      ),
                    ),
                    TextSpan(
                      text: "add new account",
                      style: TextStyle(color: Color(0xff8a8fa1), fontSize: 22),
                    ),
                  ], style: TextStyle(fontWeight: FontWeight.w600)),
                ),
                SizedBox(
                  height: 48,
                ),
                Form(
                  key: key,
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      TextFormField(
                        keyboardType: TextInputType.emailAddress,
                        validator: (val) => val.isEmpty
                            ? "Please enter email"
                            : !InputHelper.validateEmail(email)
                                ? "Please enter valid email"
                                : null,
                        onChanged: (val) {
                          setState(() {
                            email = val;
                          });
                        },
                        decoration: InputDecoration(labelText: "Email"),
                      ),
                      SizedBox(
                        height: 12,
                      ),
                      TextFormField(
                        validator: (val) =>
                            val.isEmpty ? "Please enter password" : null,
                        onChanged: (val) {
                          setState(() {
                            password = val;
                          });
                        },
                        decoration: InputDecoration(labelText: "Password"),
                      ),
                    ],
                  ),
                ),
                SizedBox(
                  height: 42,
                ),
                ContinueButton(
                  title: "Submit",
                  onPressed: () async {
                    if (!key.currentState.validate()) {
                      return;
                    }
                    BlocProvider.of<LoginBloc>(context).add(LoginSignupEvent(
                        User.named(email: email, password: password)));
                  },
                  color: Theme.of(context).primaryColor,
                  textColor: Colors.white,
                ),
                SizedBox(
                  height: 24,
                ),
                Expanded(
                  flex: 3,
                  child: Container(),
                ),
                Text(
                  "© 2020 Edumeet. All rights reserved.",
                  style: TextStyle(
                      color: Colors.black54,
                      fontSize: 15,
                      fontWeight: FontWeight.w400),
                  textAlign: TextAlign.center,
                ),
                SizedBox(
                  height: 8,
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
